@@ -1,3 +1,4 @@
+import copy
 from typing import List, Sequence, Union
 import enum
 import numpy as np
@@ -6,7 +7,7 @@ import math
 import spider
 from spider.elements.curves import ParametricCubicSpline
 from spider.elements.vehicle import VehicleState
-from spider.utils import transform
+
 from spider.utils.geometry import resample_polyline, generate_parallel_line, find_nearest_point, cumulated_distances
 
 """
@@ -54,9 +55,9 @@ class Lane:
 
         # qzl: maybe useful in FUTURE VERSIONS below
         self.bidirectional = False
-        self.traffic_flow = 0
-        self.traffic_density = 0
-        self.average_speed = 0 # qzl:这三个都是交通特性，动态地图可以给出；详见greenshields模型
+        self.traffic_flow = 0.
+        self.traffic_density = 0.
+        self.average_speed = 0. # qzl:这三个都是交通特性，动态地图可以给出；详见greenshields模型
 
 
     # def densify(self, ds=1.0): # 在geometry里面
@@ -77,6 +78,27 @@ class Lane:
             self._right_laneline = generate_parallel_line(self.centerline, self.width / 2.0, spider.DIRECTION_RIGHT)
         return self._right_laneline
 
+    def to_dict(self):
+        return {
+            "type": self.__class__.__name__,
+            "id": self.id,
+            "virtual": self.virtual,
+            "centerline": np.asarray(self.centerline).tolist(),
+
+            "left_laneline": np.asarray(self.left_laneline).tolist(),
+            "right_laneline": np.asarray(self.right_laneline).tolist(),
+            "left_lane_change": self.left_lane_change,
+            "right_lane_change": self.right_lane_change,
+
+            "width": self.width,
+            "speed_limit": self.speed_limit,
+            "bidirectional": self.bidirectional,
+
+            "traffic_flow": self.traffic_flow,
+            "traffic_density": self.traffic_density,
+            "average_speed": self.average_speed
+        }
+
 
 class LocalMap:
     def __init__(self, lanes:Sequence[Lane]=(), scene_type=ScenarioType.Multilane, section_id=-1,
@@ -100,13 +122,18 @@ class LocalMap:
     def get_centerline_info(self, lane_index):
         return self.lanes[lane_index].centerline, self.lanes[lane_index].centerline_csp
 
-    def match_lane(self, ego_veh_state: VehicleState):
+    def match_lane(self, ego_veh_state: VehicleState, return_dist=False):
+        '''
+        这里返回的变量数量不统一，最好要改过来
+        '''
+        from spider.utils import transform
+
         if len(self.lanes) == 0:
             raise ValueError("No lanes!")
 
         x, y = ego_veh_state.x(), ego_veh_state.y()
         min_idx, min_dist = -1, math.inf
-        coordinate_transformer = transform.FrenetCoordinateTransformer()
+        coordinate_transformer = transform.FrenetTransformer()
         for idx in range(len(self.lanes)):
             target_lane = self.lanes[idx]
             coordinate_transformer.set_reference_line(target_lane.centerline, target_lane.centerline_csp)
@@ -114,7 +141,11 @@ class LocalMap:
             dist = math.fabs(fstate.l)
             if dist < min_dist:
                 min_idx, min_dist = idx, dist
-        return min_idx
+
+        if return_dist:
+            return min_idx, min_dist
+        else:
+            return min_idx
 
     @classmethod
     def from_centerlines(cls, centerline_array_list: List[np.ndarray],
@@ -145,6 +176,19 @@ class LocalMap:
 
         return cls(lanes, **lmap_kwargs)
 
+    def to_dict(self):
+        return {
+            "type": self.__class__.__name__,
+            "scenario_type": self.type.name,
+            "section_id": self.section_id,
+            "lanes": [lane.to_dict() for lane in self.lanes],
+            "network": None, # 目前还没有规范化network的形式
+            "traffic_signs": None # 目前还没有规范化traffic_signs的形式
+        }
+
+    def copy(self):
+        return copy.deepcopy(self)
+
 
 
 
@@ -154,7 +198,7 @@ class RoutedLocalMap(LocalMap):
         super(RoutedLocalMap, self).__init__(lanes, scene_type, section_id, network, traffic_signs)
         # 全局导航信息，暂时用不到
         self.route = None
-        self.route_arr = None
+        self.route_arr:np.ndarray = None
         # 局部导航信息
         self.exit_lanes_idx = [] # 目标车道的序号集合
         self.distance_to_critical_point = 0.0  # todo:这个按道理需要结合自车定位特征，应该放到外面
@@ -182,6 +226,16 @@ class RoutedLocalMap(LocalMap):
 
         return self.route_arr[start_idx:end_idx]
 
+    def to_dict(self):
+        d = super(RoutedLocalMap, self).to_dict()
+        d["type"] = self.__class__.__name__
+        d['exit_lanes_idx'] = self.exit_lanes_idx
+        # d['route'] = self.route
+        d['route_arr'] = None if self.route_arr is None else self.route_arr.tolist()
+        d['distance_to_critical_point'] = self.distance_to_critical_point
+        d['traffic_light_state'] = self.traffic_light_state.name
+        return d
+
 
     # def truncate_route_arr(self, ego_x, ego_y, roi_radius):
     # 此函数弃用，roi_radius的方式不妥
