@@ -34,9 +34,10 @@ class FallbackPlanner(BasePlanner):
         # 初始状态
         ego = ego_veh_state
         x, y = ego.x(), ego.y()
-        cosyaw = np.cos(ego.yaw())
-        sinyaw = np.sin(ego.yaw())
-        vx, vy = ego.v() * cosyaw, ego.v() * sinyaw
+        vx, vy = ego.velocity.x, ego.velocity.y
+        cosyaw = vx / ego.v()
+        sinyaw = vy / ego.v()
+        # vx, vy = ego.v() * cosyaw, ego.v() * sinyaw
         # ax, ay = ego.a() * cosyaw, ego.a() * sinyaw
 
         acc = -self.config["max_deceleration"]
@@ -53,8 +54,8 @@ class FallbackPlanner(BasePlanner):
             xs, ys = np.empty_like(ts), np.empty_like(ts)
             xs[pre_idx] = x + vx * ts[pre_idx] + 0.5 * ax * ts[pre_idx] ** 2
             ys[pre_idx] = y + vy * ts[pre_idx] + 0.5 * ay * ts[pre_idx] ** 2
-            xs[~pre_idx] = vx*t_stop*0.5
-            ys[~pre_idx] = vy*t_stop*0.5
+            xs[~pre_idx] = x + vx*t_stop*0.5
+            ys[~pre_idx] = y + vy*t_stop*0.5
 
         traj = spider.elements.Trajectory.from_trajectory_array(np.array([xs, ys]).T, dt=self.dt,
             calc_derivative=True, v0=ego.v(), heading0=ego.yaw(), a0=ego.a()
