@@ -6,5 +6,8 @@ from spider.planner_zoo.PiecewiseLatticePlanner import PiecewiseLatticePlanner
 from spider.planner_zoo.ImaginaryPlanner import ImaginaryPlanner
 from spider.planner_zoo.OptimizedLatticePlanner import OptimizedLatticePlanner
 from spider.planner_zoo.FallbackPlanner import FallbackPlanner
+from spider.planner_zoo.FallbackDummyPlanner import FallbackDummyPlanner
 
-
+# import spider
+# FallbackPlanner = spider._try_import_from("spider.planner_zoo.FallbackPlanner", "FallbackPlanner")
+# ImaginaryPlanner = spider._try_import_from("spider.planner_zoo.ImaginaryPlanner", "ImaginaryPlanner")
