@@ -1,6 +1,6 @@
 import numpy as np
 import math
-from spider.elements.vector import project, rotate90
+from spider.utils.vector import project, rotate90
 import spider
 
 
@@ -130,7 +130,7 @@ def point_to_segment_distance(point: np.ndarray, segment_start:np.ndarray, segme
 #     polyline: N行2列， x列 & y列， 表示折线段上所有的顶点
 #     """
 #     if accurate_method:
-#         dists = [point_to_segment_distance(point, polyline[i], polyline[i+1])[1] for i in range(len(polyline)-1)]
+#         dists = [point_to_segment_distance(point, polyline[index], polyline[index+1])[1] for index in range(len(polyline)-1)]
 #         minidx = np.argmin(np.abs(dists))
 #         mindist = dists[minidx]
 #         return mindist
@@ -140,6 +140,31 @@ def point_to_segment_distance(point: np.ndarray, segment_start:np.ndarray, segme
 #
 #     pass
 
+# def smooth_path(path, window_size=5):
+#     """
+#     平滑路径函数
+#
+#     参数:
+#         path: numpy.ndarray, shape为 (N, 2)，包含路径中心点的坐标
+#         window_size: int, 窗口大小，用于计算平均值，默认为5
+#
+#     返回:
+#         smoothed_path: numpy.ndarray, 平滑后的路径，与输入路径形状相同
+#     """
+#     smoothed_path = np.copy(path)  # 创建一个新数组，以保留原始路径数据
+#
+#     # 遍历路径中的每个点
+#     for index in range(len(path)):
+#         # 确定窗口范围
+#         start = max(0, index - window_size // 2)
+#         end = min(len(path), index + window_size // 2 + 1)
+#
+#         # 计算窗口内点的平均值
+#         window_slice = path[start:end, :]
+#         smoothed_path[index] = np.mean(window_slice, axis=0)
+#
+#     return smoothed_path
+
 
 if __name__ == '__main__':
     xs = np.linspace(0,200,200)
