@@ -2,13 +2,12 @@
 可以思考一下如何加速
 """
 import numpy as np
-import math
 from spider.elements import TrackingBoxList
 from spider.elements.curves import ParametricCubicSpline
 from spider.utils.geometry import find_nearest_point, point_to_segment_distance, resample_polyline
 from spider.elements.trajectory import FrenetTrajectory
 from spider.elements.vehicle import KinematicState, FrenetKinematicState
-from spider.vehicle_model.bicycle import curvature2steer
+from spider.control.vehicle_model import curvature2steer
 
 # def cartesian_to_frenet(rs, rx, ry, rtheta, rkappa, rdkappa, x, y, v, a, theta, kappa):
 #     """
@@ -45,7 +44,7 @@ from spider.vehicle_model.bicycle import curvature2steer
 #     return [s0, s1, s2], [d0, d1, d2]
 
 
-class FrenetCoordinateTransformer:
+class FrenetTransformer:
     def __init__(self, reference_line:np.ndarray=None, reference_line_csp=None, resample=False, resample_resolution=1.0):
         self.refer_line_arr = None # N行2列，[[x,y]*N]
         self.refer_line_csp = None
@@ -367,7 +366,7 @@ if __name__ == '__main__':
     xs = np.linspace(0,100,101)
     ys = np.zeros_like(xs)
     centerline = np.column_stack((xs, ys))
-    transformer = FrenetCoordinateTransformer()
+    transformer = FrenetTransformer()
     transformer.set_reference_line(centerline)
 
 
